<?php
/*
* 2007-2021 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2021 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

require_once 'classes/Merchant.php';
require_once 'classes/Api.php';
include('../../config/config.inc.php');
include('../../init.php');
include_once(_PS_MODULE_DIR_.'alfred/classes/WebserviceSpecificManagementAlfredOrders.php');

class Alfred extends CarrierModule
{
   public function __construct()
    {
        $this->name             = 'alfred';
        $this->tab              = 'shipping_logistics';
        $this->version          = '2.0.0';
        $this->author           = 'Alfred24 Italia';        
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName      = $this->l('Alfred24 Easy Shipping');
        $this->description      = $this->l('Connetti il tuo store ai servizi di Alfred24 e inizia a spedire in un semplice click.');
        $this->confirmUninstall = $this->l('Disinstallare il modulo Alfred24 Easy Shipping');
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
    }

    public function install()
    {
        if (extension_loaded('curl') == false) {
            $this->_errors[] = $this->l('Devi abilitare le estensioni cURL sul tuo server per installare questo modulo');
            return false;
        }

        if (!(int)Configuration::get('ALFREDSHIPPING_CARRIER_ID')) {
            $carrier = $this->addCarrier();
            $this->addZones($carrier);
            $this->addGroups($carrier);
            $this->addRanges($carrier);
            $this->updatePrice($carrier);
        }

        include(dirname(__FILE__).'/sql/install.php');

        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('backOfficeHeader') &&
            $this->registerHook('displayCarrierExtraContent') &&
            $this->registerHook('actionCarrierUpdate') &&
            $this->registerHook('displayAdminOrder') &&
            $this->registerHook('displayPDFDeliverySlip') &&
            $this->registerHook('displayPDFInvoice') &&
            $this->registerHook('updateCarrier')&&
            $this->registerHook('actionObjectOrderHistoryAddAfter')&&
            $this->registerHook('addWebserviceResources')&&
            $this->registerHook('orderConfirmation');
    }

    public function uninstall()
    {
        include(dirname(__FILE__).'/sql/uninstall.php');

        AlfredMerchant::deAuth();
        return 
            Configuration::deleteByName('ALFRED_APITOKEN') &&
            Configuration::deleteByName('ALFRED_SHOP_TOKEN') && 
            parent::uninstall();
    }
    
    public function getContent()
    {
        $output = '';
        $has_token = false;
        if (((bool)Tools::isSubmit('submitAlfredModule')) == true) {
            $output .= $this->postProcess();
        } elseif (((bool)Tools::isSubmit('submit'.$this->name.'register')) == true) {
            $output .= $this->postProcessRegistration();
        } elseif (((bool)Tools::isSubmit('submit'.$this->name.'login')) == true) {
            $output .= $this->postProcessLogin();
        }        

        if ($token = Configuration::get('ALFRED_APITOKEN')) {
            $has_token = true;
        }

        $this->context->smarty->assign(
            array(
                'has_token' => $has_token,
                'api_token' => $token,
                'register_form' => $this->renderForm('register'),
                'login_form' => $this->renderForm('login')
            )
        );

        $output .= $this->context->smarty->fetch(_PS_MODULE_DIR_.$this->name.'/views/templates/admin/config.tpl');        

        return $output;
    }

    protected function renderForm($form)
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submit'.$this->name.$form;
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues($form),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm($form)));
    }

    protected function getConfigForm($form)
    {
        $fields = [
            'form' => [
                'legend' => [
                    'title' => null,
                    'icon' => null,
                ],
                'input' => []
            ],            
        ];

        switch ($form) {
            
            
            case 'login':

                $fields['form']['legend'] = [
                    'title' => $this->l('Accedi ad Alfred24'),
                    'icon' => 'icon-signin',
                ];

                $fields['form']['input'] = [
                    [
                        'col' => 5,
                        'type' => 'text',
                        'name' => 'email',
                        'label' => $this->l('Email'),
                        'required' => true,
                    ],
                    [
                        'col' => 5,
                        'type' => 'password',
                        'name' => 'password',
                        'label' => $this->l('Password'),
                        'required' => true,
                    ],
                ];

                $fields['form']['submit'] = [
                    'title' => $this->l('Accedi'),
                ];
                break;
        }

        return $fields;        
    }
    
    protected function getConfigFormValues($form)
    {
        $values = [];
        switch ($form) {
            case 'register':
                $values['email'] = Tools::getValue('email');
                $values['firstname'] = Tools::getValue('firstname');
                $values['lastname'] = Tools::getValue('lastname');
                $values['address'] = Tools::getValue('address');
                $values['company'] = Tools::getValue('company');
                $values['postcode'] = Tools::getValue('postcode');
                $values['locality'] = Tools::getValue('locality');
                $values['province'] = Tools::getValue('province');
                $values['region'] = Tools::getValue('region');
                $values['phone'] = Tools::getValue('phone');
                $values['password'] = Tools::getValue('password');
                break;
            
            case 'login':
                $values['email'] = Tools::getValue('email');
                $values['password'] = Tools::getValue('password');                
                break;
        }

        return $values;
    }

    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }

    }

    public function postProcessRegistration()
    {
        $response = AlfredMerchant::registerUser(
            Tools::getValue('email'),
            Tools::getValue('firstname'),
            Tools::getValue('lastname'),
            Tools::getValue('address'),
            Tools::getValue('company'),
            Tools::getValue('postcode'),
            Tools::getValue('locality'),
            Tools::getValue('province'),
            Tools::getValue('region'),
            Tools::getValue('phone'),
            Tools::getValue('password')
        );

        if ($response && isset($response['status']) && !(int)$response['status']) {
            return $this->displayError(isset($response['code']) ? $response['code'].': ' : $response['message']);
        } elseif (isset($response['user']) && isset($response['user']['token']) && $response['user']['token']) {
            AlfredMerchant::registerStore();
            return $this->displayConfirmation('Registation success');
        } else {
            return $this->displayError($this->l('An error occured, please try again'));
        }
    }

    public function postProcessLogin()
    {
        $response = AlfredMerchant::login(
            Tools::getValue('email'),
            Tools::getValue('password')
        );

        if (isset($response['response_code']) && (string)$response['response_code'] != '200') {
            return $this->displayError($response['token']);
        } elseif (
            $response &&
            isset($response['response_code']) &&
            (string)$response['response_code'] == '200' &&
            isset($response['token']) && $response['token'] &&
            Configuration::updateValue('ALFRED_APITOKEN', $response['token'])
        ) {

            //? abilito i webservice prestashop all'interno delle configurazioni utente
            Configuration::updateValue('PS_WEBSERVICE', 1);

            //? creo una chiave webservice
            $length = 32;    
            $tokenPrestashp = (substr(str_shuffle('0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'),1,$length));

            $apiAccess = new WebserviceKey();
            $apiAccess->key = $tokenPrestashp;
            $apiAccess->description = 'alfred24 plugin';
            $apiAccess->save();

            $permissions = [
                'alfredorders'      =>['GET' => 1],
                'customers'         =>['GET' => 1],
                'countries'         =>['GET' => 1],
                'currencies'        =>['GET' => 1],
                'orders'            =>['GET' => 1, 'PUT' => 1],
                'order_invoices'    =>['GET' => 1, 'PUT' => 1, 'POST'=>1],
                'order_histories'   =>['GET' => 1, 'PUT' => 1],
                'order_payments'    =>['GET' => 1, 'PUT' => 1],
                'order_details'     =>['GET' => 1, 'PUT' => 1],
                'order_carriers'    =>['GET' => 1, 'PUT' => 1],
                'order_slip'        =>['GET' => 1, 'PUT' => 1],
                'order_states'      =>['GET' => 1, 'PUT' => 1],
                'addresses'         =>['GET' => 1],
                'carriers'          =>['GET' => 1],
                'states'            =>['GET' => 1],
                'zones'             =>['GET' => 1],
              ];

            WebserviceKey::setPermissionForAccount($apiAccess->id, $permissions);
        
            $insWebservice = "INSERT INTO prestashop.ps_webservice_account_shop (id_webservice_account, id_shop) VALUES(". $apiAccess->id .", 1)";
            Db::getInstance()->execute($insWebservice);

            if(isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on') {
                $url = "https://"; 
            } else {
                $url = "http://";
            }; 
            $url.= $_SERVER['HTTP_HOST'].'/api';
            //? webhook verso alfred24 per procedura di autoconfig 

            $responseAutoConfig = AlfredMerchant::autoConfig(
                $response['token'],
                $url,
                $tokenPrestashp
            );

            //? creo il carrier alfred24 su prestashop
            AlfredMerchant::registerStore();

            //? ottengo l'id carrier
            $alfredCarrierId = Configuration::get('ALFREDSHIPPING_CARRIER_ID');

            //? ottengo l'id del modulo cash on delivery
            $id_module = Db::getInstance()->ExecuteS("select id_module from ps_module where name = 'ps_cashondelivery'");
            $idModule = $id_module[0]['id_module'];
            //? se esiste il modulo cash on delivery associato al carrier id alfred24 vado ad eliminarlo.
            if ((!is_null($idModule))) Db::getInstance()->execute("delete from ps_module_carrier where id_module =". $idModule." and id_reference = ". $alfredCarrierId);
            
            return $this->displayConfirmation('Login effettuato con successo');
        } else {
            return $this->displayError($this->l("E' stato rilevato un errore, per favore riprova"));
        }        
    }

    public function getOrderShippingCost($params, $shipping_cost)
    {
        
            $id_address_delivery = Context::getContext()->cart->id_address_delivery;
            $address = new Address($id_address_delivery);

            /**
             * Send the details through the API
             * Return the price sent by the API
             */

        return $shipping_cost;
    }

    /*
    public function getOrderShippingCost($params, $shipping_cost)
    {
        echo "<pre>";
        print_r(Context::getContext()->cookie->profile);
        echo "</pre>";
        //exit;
        if (Context::getContext()->cookie->profile == 1)
        {
            $id_address_delivery = Context::getContext()->cart->id_address_delivery;
            $address = new Address($id_address_delivery);

           
            return 10;
        }

        return $shipping_cost;
    //}
    */

    public function getOrderShippingCostExternal($params)
    {
        return true;
    }

    protected function addCarrier()
    {
        $carrier = new Carrier();

        $carrier->name          = $this->l('Alfred24');
        $carrier->is_module     = true;
        $carrier->active        = 1;
        $carrier->shipping_method=1;
        $carrier->range_behavior= 1;    //applica peso massimo se fruo
        $carrier->need_range    = 1;
        $carrier->shipping_external = true;
        //$carrier->range_behavior = 0;
        $carrier->external_module_name = $this->name;
        $carrier->max_width     = 50;
        $carrier->max_height    = 50;
        $carrier->max_depth     = 50;
        $carrier->max_weight    = 20;

        //$carrier->shipping_method = 2;
        $carrier->url            = 'https://alfred24.it/tracking/?barcode=@';

        foreach (Language::getLanguages() as $lang)
            $carrier->delay[$lang['id_lang']] = $this->l('Consegna Green al Point');

        if ($carrier->add() == true)
        {
            @copy(dirname(__FILE__).'/views/img/carrier_image.jpg', _PS_SHIP_IMG_DIR_.'/'.(int)$carrier->id.'.jpg');
            Configuration::updateValue('ALFREDSHIPPING_CARRIER_ID', (int)$carrier->id);
            return $carrier;
        }

        return false;
    }

    protected function addGroups($carrier)
    {
        $groups_ids = array();
        $groups = Group::getGroups(Context::getContext()->language->id);
        foreach ($groups as $group)
            $groups_ids[] = $group['id_group'];

        $carrier->setGroups($groups_ids);
    }

    protected function addRanges($carrier)
    {
        /*
            $range_price = new RangePrice();
            $range_price->id_carrier = $carrier->id;
            $range_price->delimiter1 = '0';
            $range_price->delimiter2 = '10000';
            $range_price->add();
        */

        $range_weight = new RangeWeight();
        $range_weight->id_carrier = $carrier->id;
        $range_weight->delimiter1 = '0';
        $range_weight->delimiter2 = '2';
        $range_weight->add();

        $range_weight->id_carrier = $carrier->id;
        $range_weight->delimiter1 = '2';
        $range_weight->delimiter2 = '5';
        $range_weight->add();

        $range_weight->id_carrier = $carrier->id;
        $range_weight->delimiter1 = '5';
        $range_weight->delimiter2 = '10';
        $range_weight->add();

        $range_weight->id_carrier = $carrier->id;
        $range_weight->delimiter1 = '10';
        $range_weight->delimiter2 = '15';
        $range_weight->add();

        $range_weight->id_carrier = $carrier->id;
        $range_weight->delimiter1 = '15';
        $range_weight->delimiter2 = '20';
        $range_weight->add();  
    }


    protected function updatePrice($carrier){
        //Prezzi Listino Poste Italiane ( Standard ) 20 Merchant 
        $price=array(5.8,7.10,10.40,12.5,14.10);

        try{
        
            $i=0;
            $range = Db::getInstance()->executeS('select * from ps_range_weight prw   where prw.id_carrier ='.$carrier->id.' order by 1'); 
           
            foreach($range as $r){
                $updatePrice="update ps_delivery set id_shop=null, id_shop_group=null, price=".$price[$i]." where id_carrier=".$carrier->id." and id_range_weight=".$r['id_range_weight'];
                Db::getInstance()->execute($updatePrice);
                $i++;
            }
        }
        catch(Exception $e){
            echo $e->getMessage();
        }
    }

    protected function addZones($carrier)
    {
        $carrier->addZone(1); // X Alfred24 attivolo solo Europa
/*       
        $zones = Zone::getZones();
        foreach ($zones as $zone)
            $carrier->addZone($zone['id_zone']);
*/      
    }

    /**
    * Add the CSS & JavaScript files you want to be loaded in the BO.
    */
    public function hookBackOfficeHeader()
    {
        $this->context->controller->addCSS($this->_path.'views/css/back.css');
        $this->context->controller->addJS($this->_path.'views/js/back.js');
    }

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookHeader()
    {
        $this->context->controller->addJS($this->_path.'/views/js/front.js');
        $this->context->controller->addCSS($this->_path.'/views/css/front.css');
    }

   
    public function hookDisplayCarrierExtraContent($params)
    {

        $this->context->smarty->assign(
            array(
                'alfred_search_url' => $this->context->link->getModuleLink(
                    $this->name,
                    'search',
                    array(
                        'ajax' => 1
                    )
                )
            )
            
        );
        $display = $this->context->smarty->fetch($this->local_path.'views/templates/front/carrierextraContent.tpl');

        return $display;
        
    }

    public function hookActionCarrierUpdate($params)
    {
        $old_id_carrier = (int)$params['id_carrier'];
        $new_id_carrier = (int)$params['carrier']->id;

        $alfred_carrier_id = Configuration::get('ALFREDSHIPPING_CARRIER_ID');

        if($old_id_carrier == $alfred_carrier_id) {
            Configuration::updateValue('ALFREDSHIPPING_CARRIER_ID', $new_id_carrier);
        }
        
    }

    public function hookDisplayAdminOrder($params) {

        $base_url_site = Tools::getHttpHost(true).__PS_BASE_URI__;
        $id_order = (int)$params['id_order'];
        $order = new Order($id_order);
        $id_cart = $order->id_cart;

        $order_carrier = new Carrier($order->id_carrier);
        $order_carrier_id_reference = $order_carrier->id_reference;

        $alfred_carrier = new Carrier((int)Configuration::get('ALFREDSHIPPING_CARRIER_ID'));
        $alfred_carrier_id_reference = $alfred_carrier->id_reference;
        

        if($order_carrier_id_reference == $alfred_carrier_id_reference) {
            $pickup_details =  Db::getInstance()->getValue('select pickup_point_details from ' . _DB_PREFIX_ . 'alfred_pick_point where id_cart='.$id_cart);            
            $urlLabel =  Db::getInstance()->getValue('select urlLabel from ' . _DB_PREFIX_ . 'alfred_urlLabel where id_order='.$id_order);


            $this->context->smarty->assign(
                array(
                    'pickup_details' =>  json_decode($pickup_details , true),
                    'urlLabel' =>  $urlLabel,
                    'id_order' =>  $id_order,
                    'base_url_site' =>  $base_url_site,
                )
            );
            $display = $this->context->smarty->fetch($this->local_path.'views/templates/admin/getbest_courier.tpl');

            return $display;
        }
    }

    public function hookDisplayAdminOrderLeft($param)
    {
        return '<b>hookDisplayAdminOrder</b>';
    }

    
    public function hookAddWebserviceResources()
    {
        return array(
            'alfredorders' => array(
                'description' => 'Alfred Order',
                'specific_management' => true,
            )
        );
    }

    private function getAlfredStatus() {
        $alfredStatus = Db::getInstance()->executeS('SELECT id_order_state FROM '._DB_PREFIX_.'order_state_lang WHERE name = \'Alfred_Status\' and id_lang = 1'); 
        $alfredStatus = $alfredStatus[0]['id_order_state'];
        return $alfredStatus;
    }

    private function getAlfredCarrier() {
        $alfredCarrier = Db::getInstance()->executeS('SELECT id_carrier FROM '._DB_PREFIX_.'carrier WHERE name LIKE \'%Alfred%\' '); 
        $alfredCarrier = $alfredCarrier[0]['id_carrier'];
        return $alfredCarrier;
    }

    public function hookActionObjectOrderHistoryAddAfter($params) {
        $orderHistory = $params['object'];
        $oOrder = new Order($params['object']->id_order);
        $alfredStatus = $this->getAlfredStatus();
        $alfredCarrier = $this->getAlfredCarrier();
        if($orderHistory->id_order_state == Configuration::get('PS_OS_PAYMENT') && $params['cart']->id_carrier == $alfredCarrier) {
            $orderHistory->changeIdOrderState($alfredStatus,$oOrder->id);
        }
    }

    public function hookDisplayPDFDeliverySlip($params)
    {
        return $this->hookDisplayPDFInvoice($params);
    }

    public function hookDisplayPDFInvoice($params)
    {
        $id_order = (int)$params['object']->id_order;
        $order = new Order(
            (int)$id_order
        );
        if ((int)$order->id_carrier != (int)Configuration::get('ALFREDSHIPPING_CARRIER_ID')) {
            return;
        }
        $sql = new DbQuery;
        $sql->select('*');
        $sql->from(
            'alfred_pick_point'
        );
        $sql->where(
            'id_cart = '.(int)$order->id_cart
        );
        $alfred = Db::getInstance()->getRow($sql);
        $data_point = json_decode($alfred['pickup_point_details'],true);
  
        if ($data_point) {
            $stores = $this->getTemplateVarStores();
            foreach ($stores as $tpl_store) {
                //if ((int)$tpl_store['id_store'] == (int)$alfred['id_store']) {
                    $obj_merged = (array)$tpl_store;
                    $store = $obj_merged;
                //}
            }
            $this->context->smarty->assign(array(
                'alfred_store' => $store,
                'alfred_data' => $data_point
            ));
            return $this->display(__FILE__, 'views/templates/hook/invoice.tpl');
        }
    }

    public function getTemplateVarStores()
    {
        $stores = Store::getStores($this->context->language->id);
        foreach ($stores as &$store) {
            unset($store['active']);
            // Prepare $store.address
            $address = new Address();
            $store['address'] = [];
            $attr = ['address1', 'address2', 'postcode', 'city', 'id_state', 'id_country'];
            foreach ($attr as $a) {
                $address->{$a} = $store[$a];
                $store['address'][$a] = $store[$a];
                unset($store[$a]);
            }
            $store['address']['formatted'] = AddressFormat::generateAddress($address, [], '<br />');
        }

        return $stores;
    }

    public function hookOrderConfirmation($params)
    {
        
        if(isset($params['order'])){
           //RECUPERO APITOKENT SU ALFRED24 DELL'UTENTE IN SESSIONE PRESTASHOP
            $apitokenAlfred = Configuration::get('ALFRED_APITOKEN') ;

            if(!is_null($apitokenAlfred) && !empty($apitokenAlfred)){//avvio la chiamata ad Alfred24

                //OTTENGO ID ORDINE
                $order_id = Tools::getValue('id_order');

                //OTTENGO I DETTAGLI DELL'ORDINE SPECIFICO
                $order = new Order($order_id);

                //OTTENGO L'ID DEL CART ASSOCIATO ALL'ORDINE
                $id_cart = $order->id_cart;
                
                //OTTENGO IL DETTAGLIO CLIENTE PER L'ORDINE SPECIFICO
                $customer = new Customer($order->id_customer);

                //OTTENGO I DATI DI DELIVERY PER LO SPECIFICO ORDINE
                $address_delivery = new Address($order->id_address_delivery);

                //OTTENGO IL DETTAGLIO DEI PRODOTTI ACQUISTATI E CREO LA STRUTTURA DA INVIARE ALLA NOSTRA API DI IMPORTAZIONE
                $ProductDetailObject = new OrderDetail;
                $product_detail = $ProductDetailObject->getList($order_id); //params['order']->id);

                //print_r($product_detail);

                //$prodottiii = new Product;
                //print_r($prodottiii);

                $product=array();
                foreach($product_detail as $pd){
                    $product[]=array(
                        "order_id"      => $order->id,
                        "description"   => $pd['product_name'],
                        "qty"           => $pd['product_quantity'],
                        "weight"        => $pd['product_weight'],
                        "price"         => $pd['total_price_tax_incl']
                    );
                }
   
                //SETTO UN VALORE DI DEFAULT PER IL POINT SELEZIONATO - NESSUNO
                $idDeliveryPoint="";
                
                //OTTENGO L'ID POINT SELEZIONATO
                /* $queryCart="select * from ps_alfred_pick_point papp where papp.id_cart =".$id_cart; 
                $dataPoint =  Db::getInstance()->ExecuteS($queryCart); 
                if(isset($dataPoint[0]['idPoint']) && $dataPoint[0]['idPoint']>0) $idDeliveryPoint=$dataPoint[0]['idPoint']; */

                $idPoint = Db::getInstance()->getValue('Select idPoint from '. _DB_PREFIX_ .'alfred_pick_point where id_cart='.$id_cart);
                if(isset($idPoint) && $idPoint>0) $idDeliveryPoint=$idPoint;
                
                
                echo "<script>console.log('Debug Objects idPoint: " . json_encode($idDeliveryPoint,true) . "' );</script>";

                $numeroTelefono = "";
                
                if($address_delivery->phone != ""){
                    $numeroTelefono = $address_delivery->phone;
                } else if($address_delivery->phone_mobile != ""){
                    $numeroTelefono = $address_delivery->phone_mobile;
                } else {
                    $numeroTelefono = "3333333333";
                };

                echo "<script>console.log('Debug Objects Telefono: " . json_encode($numeroTelefono,true) . "' );</script>";
                
                
                $parametriSpecificiPrestaShop=''
                //.' "id" : "'.$order->id.'", '
                .' "id_shop":           "'.$order->id_shop.'",'
                //.' "reference": "'.$order->reference.'",'
                .' "id_shop_group":     "'.$order->id_shop_group.'",'
                .' "id_address_delivery": "'.$order->id_address_delivery.'",'
                .' "id_address_invoice" : "'.$order->id_address_invoice.'",'
                .' "id_cart"            : "'.$order->id_cart.'",'
                .' "id_currency"        : "'.$order->id_currency.'",'
                .' "id_lang"            : "'.$order->id_lang.'",'
                .' "id_customer"        : "'.$order->id_customer.'",'
                .' "id_carrier"         : "'.$order->id_carrier.'",'
                .' "module"             : "'.$order->module.'",'
                .' "payment"            : "'.$order->payment.'",'
                .' "total_paid"         : "'.$order->total_paid.'",'
                .' "total_paid_tax_incl": "'.$order->total_paid_tax_incl.'",'
                .' "total_paid_tax_excl": "'.$order->total_paid_tax_excl.'",'
                .' "total_paid_real"    : "'.$order->total_paid_real.'",'
                .' "total_products"     : "'.$order->total_products.'",'
                .' "total_products_wt"  : "'.$order->total_products_wt.'",'
                .' "secure_key"         : "'.$order->secure_key.'",'
                .' "conversion_rate"    : "'.$order->conversion_rate.'",'
                .' "total_shipping_tax_incl" : "'.$order->total_shipping_tax_incl.'",'
                .' "total_shipping_tax_excl" : "'.$order->total_shipping_tax_excl.'", '
                .' "total_shipping"     : "'.$order->total_shipping.'",';
               

                $jsonToAlfred='
                {
                    "apitoken":         "'.$apitokenAlfred.'",
                    "orderNumber":      "'.$order->id.'",
                    "orderReference":   "'.$order->reference.'",
                    '.$parametriSpecificiPrestaShop.'
                    "payment_status":   "'.$order->payment.'", 
                    "payment_method":   "'.$order->module.'", 
                    "id_connector":     "1",
                    "delivery_Point":   "'.$idDeliveryPoint.'",
                    "id_carrier":       "'.$order->id_carrier.'",
                    "receiver": [
                        {
                            "lastname": "'.$customer->lastname.'",
                            "firstname":"'.$customer->firstname.'",
                            "address":  "'.$address_delivery->address1.' '.$address_delivery->address2.'",
                            "postcode": "'.$address_delivery->postcode.'",
                            "city":     "'.$address_delivery->city.'",
                            "phone":    "'.$numeroTelefono.'",
                            "email":    "'.$customer->email.'"
                        }
                    ],
                    "products": '.json_encode($product,true).'
                }';
                

                $url='https://api.alfred24.it/wd/ImportOrder.php';

                $headers = array(
                    "Accept:application/json",
                    "Content-Type:application/json",
                    "Cache-Control:no-cache"
                );
                
                $ch = curl_init($url);
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                curl_setopt($ch, CURLHEADER_SEPARATE, true);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "PUT");
                curl_setopt($ch, CURLOPT_POST, 1);
                curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonToAlfred);
                $data = curl_exec($ch);
                echo "<script>console.log('Debug Objects: " . json_encode($data,true) . "' );</script>";
                curl_close($ch);

            }
            
        }        
 }

 
}


?>